@@ -2,7 +2,7 @@
 #include <blockdev/utils.h>
 
 
-#define BD_CRYPTO_LUKS_METADATA_SIZE (2 * 1048576ULL)
+#define BD_CRYPTO_LUKS_METADATA_SIZE G_GUINT64_CONSTANT (2097152ULL) // 2 MiB
 
 GQuark  bd_crypto_error_quark (void);
 
@@ -32,6 +32,7 @@ typedef enum {
     BD_CRYPTO_TECH_TRUECRYPT,
     BD_CRYPTO_TECH_ESCROW,
     BD_CRYPTO_TECH_INTEGRITY,
+    BD_CRYPTO_TECH_BITLK,
 } BDCryptoTech;
 
 typedef enum {
@@ -833,3 +834,31 @@ gboolean  bd_crypto_tc_close (const gchar *tc_device, GError **error);
  */
 gboolean  bd_crypto_escrow_device (const gchar *device, const gchar *passphrase, const gchar *cert_data, const gchar *directory, const gchar *backup_passphrase, GError **error);
 
+
+/**
+ * bd_crypto_bitlk_open:
+ * @device: the device to open
+ * @name: name for the BITLK device
+ * @pass_data: (array length=data_len): a passphrase for the BITLK volume (may contain arbitrary binary data)
+ * @data_len: length of the @pass_data buffer
+ * @read_only: whether to open as read-only or not (meaning read-write)
+ * @error: (out): place to store error (if any)
+ *
+ * Returns: whether the @device was successfully opened or not
+ *
+ * Tech category: %BD_CRYPTO_TECH_BITLK-%BD_CRYPTO_TECH_MODE_OPEN_CLOSE
+ */
+gboolean  bd_crypto_bitlk_open (const gchar *device, const gchar *name, const guint8* pass_data, gsize data_len, gboolean read_only, GError **error);
+
+
+/**
+ * bd_crypto_bitlk_close:
+ * @bitlk_device: BITLK device to close
+ * @error: (out): place to store error (if any)
+ *
+ * Returns: whether the given @bitlk_device was successfully closed or not
+ *
+ * Tech category: %BD_CRYPTO_TECH_BITLK-%BD_CRYPTO_TECH_MODE_OPEN_CLOSE
+ */
+gboolean  bd_crypto_bitlk_close (const gchar *bitlk_device, GError **error);
+
