@@ -404,15 +404,30 @@ static gboolean ext_repair (const gchar *device, gboolean unsafe, const BDExtraA
     const gchar *args_progress[7] = {"e2fsck", "-f", unsafe ? "-y" : "-p", "-C", "1", device, NULL};
     const gchar *args[5] = {"e2fsck", "-f", unsafe ? "-y" : "-p", device, NULL};
     gint status = 0;
+    gboolean ret = FALSE;
 
     if (!check_deps (&avail_deps, DEPS_E2FSCK_MASK, deps, DEPS_LAST, &deps_check_lock, error))
         return FALSE;
 
     if (bd_utils_prog_reporting_initialized ()) {
-        return bd_utils_exec_and_report_progress (args_progress, extra, extract_e2fsck_progress, &status, error);
+        ret = bd_utils_exec_and_report_progress (args_progress, extra, extract_e2fsck_progress, &status, error);
     } else {
-        return bd_utils_exec_and_report_status_error (args, extra, &status, error);
+        ret = bd_utils_exec_and_report_status_error (args, extra, &status, error);
     }
+
+    if (!ret) {
+        if (status == 1) {
+            /* no error should be reported for exit code 1 - File system errors corrected */
+            g_clear_error (error);
+            ret = TRUE;
+        } else if (status == 2) {
+            /* no error should be reported for exit code 2 - File system errors corrected, system should be rebooted */
+            g_warning ("File system errors on %s were successfully corrected, but system reboot is advised.", device);
+            g_clear_error (error);
+            ret = TRUE;
+        }
+    }
+    return ret;
 }
 
 /**
@@ -565,7 +580,13 @@ static BDFSExtInfo* get_ext_info_from_table (GHashTable *table, gboolean free_ta
         g_free (ret->label);
         ret->label = g_strdup ("");
     }
+
     ret->uuid = g_strdup ((gchar*) g_hash_table_lookup (table, "Filesystem UUID"));
+    if (!ret->uuid || g_strcmp0 (ret->uuid, "<none>") == 0) {
+        g_free (ret->uuid);
+        ret->uuid = g_strdup ("");
+    }
+
     ret->state = g_strdup ((gchar*) g_hash_table_lookup (table, "Filesystem state"));
 
     value = (gchar*) g_hash_table_lookup (table, "Block size");
